==> gcstar_0.5.0.orig.tar.gz: gcstar/lib/gcstar/GCLang/IT/GCModels/GCbooks.pm <==
{
    package GCLang::IT::GCModels::GCbooks;

    use utf8;
###################################################
#
#  Copyright 2005-2006 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Books collection',
        Items => 'Books',
        NewItem => 'New book',
    
        Isbn => 'ISBN',
        Title => 'Title',
        Cover => 'Cover',
        Authors => 'Authors',
        Publisher => 'Publisher',
        Publication => 'Publication date',
        Language => 'Language',
        Genre => 'Genre',
        Bookdescription => 'Description',
        Pages => 'Pages',
        Read => 'Read',
        Rating => 'Rating',
        Acquisition => 'Acquisition date',
        Location => 'Location',
        Edition => 'Edition',
        Format => 'Format',
        Comments => 'Comments',
        Url => 'Web page',

        General => 'General',
        Details => 'Details',

        ReadNo => 'Not read',
        ReadYes => 'Read',
     );
}

1;

==> gcstar_1.1.1.orig.tar.gz: gcstar/lib/gcstar/GCLang/IT/GCModels/GCbooks.pm <==
{
    package GCLang::IT::GCModels::GCbooks;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Books collection',
        Items => 'Books',
        NewItem => 'New book',
    
        Isbn => 'ISBN',
        Title => 'Title',
        Cover => 'Cover',
        Authors => 'Authors',
        Publisher => 'Publisher',
        Publication => 'Publication date',
        Language => 'Language',
        Genre => 'Genre',
        Bookdescription => 'Description',
        Pages => 'Pages',
        Read => 'Read',
        Rating => 'Rating',
        Acquisition => 'Acquisition date',
        Edition => 'Edition',
        Format => 'Format',
        Comments => 'Comments',
        Url => 'Web page',
        Translator => 'Translator',
        Artist => 'Artist',

        General => 'General',
        Details => 'Dettagli',

        ReadNo => 'Not read',
        ReadYes => 'Read',
     );
}

1;
